#
# spec file for package diun
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           diun
Version:        4.29.0
Release:        1.1
Summary:        Receive notifications when an image is updated on a Docker registry
License:        MIT
URL:            https://github.com/crazy-max/diun
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source11:       %{name}.service
Source12:       %{name}.sysusers
BuildRequires:  go >= 1.22
BuildRequires:  sysuser-tools
%{sysusers_requires}

%description
Diun is a CLI application written in Go to receive notifications when a Docker
image is updated on a Docker registry.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -ldflags="-X main.version=v%{version}" \
   -o bin/%{name} ./cmd/

# user and group
%sysusers_generate_pre %{SOURCE12} %{name} %{name}.conf

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

install -d -m 0750 %{buildroot}%{_sysconfdir}/%{name}/
install -d -m 0750 %{buildroot}%{_sharedstatedir}/%{name}/

install -d -m 0755 %{buildroot}%{_unitdir}/
install -D -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/%{name}.service

install -D -m 0644 %{SOURCE12} %{buildroot}%{_sysusersdir}/%{name}.conf

%pre -f %{name}.pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%{_sysusersdir}/%{name}.conf
%dir %attr(750,root,%{name}) %{_sysconfdir}/%{name}/
%dir %attr(750,%{name},%{name}) %{_sharedstatedir}/%{name}/

%changelog
* Fri Dec 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.29.0:
  * Topics support for Telegram notifications (#1308)
  * Webhook url as secret support for Discord, Slack and Teams
    notifications (#1302)
  * Enhance error message for JSON decode response issues for
    Gotify, ntfy and RocketChat (#1309)
  * Fix TLS configuration handling for Nomad provider (#1178)
  * Go 1.23 (#1286)
  * Alpine Linux 3.21 (#1286)
  * Switch to github.com/containerd/platforms v0.2.1 (#1287)
  * Switch to github.com/rabbitmq/amqp091-go v1.10.0 (#1288)
  * Bump dario.cat/mergo to 1.0.1 (#1301)
  * Bump github.com/alecthomas/kong from 0.9.0 to 1.6.0 (#1298)
  * Bump github.com/containers/image/v5 to 5.33.0 (#1274 #1284)
  * Bump github.com/distribution/reference from 0.5.0 to 0.6.0
    (#1183)
  * Bump github.com/docker/docker to 27.3.1+incompatible (#1181
    [#1275] #1291)
  * Bump github.com/eclipse/paho.mqtt.golang to 1.5.0 (#1299)
  * Bump github.com/go-playground/validator/v10 to 10.23.0 (#1179
    [#1191] #1297)
  * Bump github.com/gregdel/pushover to 1.3.1 (#1164)
  * Bump github.com/jedib0t/go-pretty/v6 to 6.6.5 (#1167 #1300)
  * Bump github.com/microcosm-cc/bluemonday to 1.0.27 (#1294)
  * Bump github.com/moby/buildkit to 0.17.3 (#1160 #1312)
  * Bump github.com/panjf2000/ants/v2 to 2.10.0 (#1198)
  * Bump github.com/PaulSonOfLars/gotgbot/v2 to 2.0.0-rc.30 (#1185
    [#1278])
  * Bump github.com/rs/zerolog to 1.33.0 (#1186)
  * Bump github.com/stretchr/testify to 1.10.0 (#1295)
  * Bump go.etcd.io/bbolt to 1.3.11 (#1187 #1292)
  * Bump golang.org/x/crypto to 0.31.0 (#1271)
  * Bump golang.org/x/mod to 0.22.0 (#1188 #1296)
  * Bump golang.org/x/net to 0.23.0 (#1157)
  * Bump golang.org/x/sys to 0.25.0 (#1184 #1240)
  * Bump google.golang.org/grpc to 1.67.0 (#1171 #1293)
  * Bump google.golang.org/grpc/cmd/protoc-gen-go-grpc to 1.5.1
    (#1224)
  * Bump google.golang.org/protobuf to 1.35.2 (#1277)
  * Bump k8s.io/client-go to 0.32.0 (#1280)
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.28.0:
  * Update CHANGELOG
  * chore(deps): bump golang.org/x/sys from 0.18.0 to 0.19.0
  * dockerfile: add tzdata package
  * chore(deps): bump golang.org/x/mod from 0.16.0 to 0.17.0
  * chore(deps): bump google.golang.org/grpc from 1.62.1 to 1.63.0
  * chore(deps): bump github.com/panjf2000/ants/v2 from 2.9.0 to 2.9.1
* Tue Aug 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package diun: Docker Image Update Notifier is a CLI
  application to receive notifications when a Docker image is
  updated on a Docker registry
